@@ -3,26 +3,32 @@
 
 #include <time.h>
 
+#define LOG_RFC3164 0
+#define LOG_RFC5424 1
+
 typedef struct {
 
     /* configuration */
-    int    priority;        /* RFC3164/4.1.1 PRI Part */
-    char*  sender;          /* sender hostname */
-    char*  name;            /* sending program name */
-    int    pid;             /* sending program pid */
+    int    priority;            /* RFC3164/4.1.1 PRI Part */
+    char*  sender;              /* sender hostname */
+    char*  name;                /* sending program name */
+    int    pid;                 /* sending program pid */
+    int    format;              /* RFC3164 or RFC5424 */
 
     /* resource handles */
-    int    sock;            /* socket fd */
+    int    sock;                /* socket fd */
 
     /* internal state */
-    time_t last_time;       /* time when the prefix was last generated */
-    char*  linebuf;         /* log line, including prefix and message */
-    int    bufsize;         /* current size of linebuf */
-    size_t prefix_len;      /* length of the prefix string */
-    char*  msg_start;       /* pointer into linebuf after end of prefix */
+    time_t last_time;           /* time when the prefix was last generated */
+    char*  linebuf;             /* log line, including prefix and message */
+    int    bufsize;             /* current size of linebuf */
+    size_t prefix_len;          /* length of the prefix string */
+    char*  msg_start;           /* pointer into linebuf after end of prefix */
+    const char* time_format;    /* strftime format string */
+    const char* msg_format;     /* snprintf format string */
 
     /* error reporting */
-    const char* err;        /* error string */
+    const char* err;            /* error string */
 
 } LogSyslogFast;
 
@@ -38,6 +44,7 @@ void LSF_set_severity(LogSyslogFast* logger, int severity);
 int LSF_set_sender(LogSyslogFast* logger, const char* sender);
 int LSF_set_name(LogSyslogFast* logger, const char* name);
 void LSF_set_pid(LogSyslogFast* logger, int pid);
+int LSF_set_format(LogSyslogFast* logger, int format);
 
 int LSF_get_priority(LogSyslogFast* logger);
 int LSF_get_facility(LogSyslogFast* logger);
@@ -45,6 +52,7 @@ int LSF_get_severity(LogSyslogFast* logger);
 const char* LSF_get_sender(LogSyslogFast* logger);
 const char* LSF_get_name(LogSyslogFast* logger);
 int LSF_get_pid(LogSyslogFast* logger);
+int LSF_get_format(LogSyslogFast* logger);
 
 int LSF_get_sock(LogSyslogFast* logger);
 
